"use strict";
/*
 * @license
 * Copyright (c) 2019 Cristian Abrante. All rights reserved.
 * Licensed under the MIT License. See LICENSE in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FloatingGenerator = void 0;
const utils_1 = require("../../utils");
const floating_1 = require("./../../../individual/numeric/floating");
const base_1 = require("./../base");
/**
 * ## Floating generator
 * Generates a [[FloatingIndividual]].
 */
class FloatingGenerator extends base_1.NumericGenerator {
    /**
     * Generates a gene with the specified
     * params.
     * @param params of the generator.
     * @return the generated gene.
     */
    generateGene(params) {
        return utils_1.Generator.generateFloating(params.range, params.engine);
    }
    /**
     * Construct the [[FloatingIndividual]] with
     * the specified genotype and range.
     * @param genotype of the generated individual.
     * @param params of the generator.
     * @return Constructed [[FloatingIndividual]] from genotype.
     */
    construct(genotype, params) {
        return new floating_1.FloatingIndividual(genotype, params.range);
    }
}
exports.FloatingGenerator = FloatingGenerator;
//# sourceMappingURL=FloatingGenerator.js.map