"use strict";
/*
 * @license
 * Copyright (c) 2019 Cristian Abrante. All rights reserved.
 * Licensed under the MIT License. See LICENSE in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegerGenerator = void 0;
const utils_1 = require("../../utils/");
const integer_1 = require("./../../../individual/numeric/integer");
const base_1 = require("./../base");
/**
 * ## IntegerGenerator
 * Generates an [[IntegerIndividual]].
 */
class IntegerGenerator extends base_1.NumericGenerator {
    /**
     * Generates a gene with the specified
     * params.
     * @param params of the generator.
     * @return the generated gene.
     */
    generateGene(params) {
        return utils_1.Generator.generateInteger(params.range, params.engine);
    }
    /**
     * Constructs the individual given
     * the genotype and the range.
     * @param genotype of the individual.
     * @param params of the generator.
     * @return [[NumericIndividual]] constructed with the given params.
     */
    construct(genotype, params) {
        return new integer_1.IntegerIndividual(genotype, params.range);
    }
}
exports.IntegerGenerator = IntegerGenerator;
//# sourceMappingURL=IntegerGenerator.js.map