"use strict";
/*
 * @license
 * Copyright (c) 2021 Cristo Navarro.
 * Copyright (c) 2020 Francisco Cruz.
 * Copyright (c) 2019 Cristian Abrante.
 * All rights reserved.
 * Licensed under the MIT License. See LICENSE in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Node = void 0;
/**
 * ## Node
 * Node is an element of a simple linked list. It contains some data and a
 * pointer to the next node in the list.
 */
class Node {
    /**
     * Constructor of the class.
     * Initializes the data of the node.
     * @param data Data to initialize the node
     */
    constructor(data) {
        /**
         * Pointer to the next node in the list.
         */
        this.nextNode = null;
        this.nodeData = data;
    }
    /**
     * Getter for the data of the node.
     * @return Data of the node.
     */
    get data() {
        return this.nodeData;
    }
    /**
     * Setter for the data of the node.
     * @param newData New data for the node
     */
    set data(newData) {
        this.nodeData = newData;
    }
    /**
     * Getter for the pointer of the next node in the list.
     * @return Pointer to the next node.
     */
    get next() {
        return this.nextNode;
    }
    /**
     * Setter of the pointer to the next node.
     * @param nextNode New pointer to the next node
     */
    set next(nextNode) {
        this.nextNode = nextNode;
    }
}
exports.Node = Node;
//# sourceMappingURL=Node.js.map