"use strict";
/*
 * @license
 * Copyright (c) 2019 Cristian Abrante. All rights reserved.
 * Licensed under the MIT License. See LICENSE in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegerNormalizer = void 0;
const NumericRange_1 = require("../../base/NumericRange");
class IntegerNormalizer {
    /**
     * Normalize the given gene, rounding it.
     * @param gene that we want to normalize.
     */
    static normalize(gene) {
        return Math.round(gene);
    }
    /**
     * Normalizes a complete numeric genotype.
     * @param genotype that we want to normalize.
     */
    static normalizeGenotype(genotype) {
        return genotype.map(gene => this.normalize(gene));
    }
    /**
     * Normalizes a given numeric range.
     * @param range that we want to normalize.
     * @return the normalized range.
     */
    static normalizeRange(range) {
        return new NumericRange_1.NumericRange(this.normalize(range.lowest), this.normalize(range.highest));
    }
}
exports.IntegerNormalizer = IntegerNormalizer;
//# sourceMappingURL=IntegerNormalizer.js.map