"use strict";
/*
 * @license
 * Copyright (c) 2021 Cristo Navarro.
 * Copyright (c) 2020 Francisco Cruz.
 * Copyright (c) 2019 Cristian Abrante.
 * All rights reserved.
 * Licensed under the MIT License. See LICENSE in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.GeneRelocationMutation = void 0;
const utils_1 = require("../../generator/utils");
const individual_1 = require("../../individual");
const UniformListMutation_1 = require("./UniformListMutation");
/**
 * ## Gene Relocation Mutation
 * Class that implements a mutation operator for List Individuals.
 *
 * This operator is applied to each gene of the genotype and moves one node
 * of the list corresponding to the current gene, to a different gene. Both the
 * node, and the other gene are chosen randomly.
 */
class GeneRelocationMutation extends UniformListMutation_1.UniformListMutation {
    /**
     * Mutation operator that is applied to the gene in the specified index.
     * The operator moves a node of the current list to another one.
     * @param individual Individual that the operator is applied on
     * @param index Index of the current gene
     * @param params Operator parameters
     */
    mutateGeneUniformly(individual, index, params) {
        const currentGene = individual.get(index);
        const individualRange = new individual_1.NumericRange(0, individual.length() - 1);
        let otherGeneIndex = utils_1.Generator.generateInteger(individualRange);
        if (individual.length() > 1) {
            while (index === otherGeneIndex) {
                otherGeneIndex = utils_1.Generator.generateInteger(individualRange);
            }
        }
        const otherGene = individual.get(otherGeneIndex);
        let currentIndex = params.initialIndex;
        let otherIndex = params.initialIndex;
        if (params.initialIndex <= currentGene.length() - 1 && params.initialIndex <= otherGene.length()) {
            if (params.initialIndex < currentGene.length() - 1) {
                const currentRange = new individual_1.NumericRange(params.initialIndex, currentGene.length() - 1);
                currentIndex = utils_1.Generator.generateInteger(currentRange);
            }
            if (params.initialIndex < otherGene.length()) {
                const otherRange = new individual_1.NumericRange(params.initialIndex, otherGene.length());
                otherIndex = utils_1.Generator.generateInteger(otherRange);
            }
            const currentData = currentGene.get(currentIndex);
            currentGene.erase(currentIndex);
            otherGene.insert(otherIndex, currentData);
        }
    }
}
exports.GeneRelocationMutation = GeneRelocationMutation;
//# sourceMappingURL=GeneRelocationMutation.js.map