"use strict";
/*
 * @license
 * Copyright (c) 2019 Cristian Abrante. All rights reserved.
 * Licensed under the MIT License. See LICENSE in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegerReader = void 0;
const integer_1 = require("../../../individual/numeric/integer/");
const base_1 = require("../base/");
/**
 * ## Integer Reader
 * Reads an [[IntegerIndividual]] from a definition.
 * The format of the definition is the following
 * ```
 * 3 5 7 23   // OK
 * -4 -5 -8   // OK (Negative numbers allowed).
 * ```
 */
class IntegerReader extends base_1.NumericReader {
    constructor() {
        super(...arguments);
        this.tokenDefinition = [
            {
                token: /^[+-]?\d+$/,
                value: (token) => Number.parseInt(token, 10),
            },
        ];
    }
    /**
     * Reads a definition and converts
     * into an [[IntegerIndividual]].
     * @param definition of the individual.
     * @return the read individual.
     * @throws Error if definition is not correct.
     */
    read(definition) {
        const genotype = this.getGenotype(this.tokenize(definition));
        return new integer_1.IntegerIndividual(genotype);
    }
}
exports.IntegerReader = IntegerReader;
//# sourceMappingURL=IntegerReader.js.map